@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -20,14 +20,13 @@
 
 #ifndef INSERTTABLEWIDGET_H
 #define INSERTTABLEWIDGET_H
-#include "kpimtextedit_export.h"
 
 #include <QWidget>
 
 #include <QTextLength>
 
 namespace KPIMTextEdit {
-class KPIMTEXTEDIT_EXPORT InsertTableWidget : public QWidget
+class InsertTableWidget : public QWidget
 {
     Q_OBJECT
 public:
