@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -56,7 +56,7 @@ TextReplaceWidget::~TextReplaceWidget()
 {
 }
 
-QLineEdit *TextReplaceWidget::replace() const
+QLineEdit *TextReplaceWidget::replaceLineEdit() const
 {
     return mReplace;
 }
@@ -102,6 +102,9 @@ TextFindWidget::TextFindWidget(QWidget *parent)
     mWholeWordAct = optionsMenu->addAction(i18n("Whole word"));
     mWholeWordAct->setCheckable(true);
 
+    mRegExpAct = optionsMenu->addAction(i18n("Regular Expression"));
+    mRegExpAct->setCheckable(true);
+
     optionsBtn->setMenu(optionsMenu);
     lay->addWidget(optionsBtn);
 
@@ -109,6 +112,7 @@ TextFindWidget::TextFindWidget(QWidget *parent)
     connect(mFindPrevBtn, &QPushButton::clicked, this, &TextFindWidget::findPrev);
     connect(mCaseSensitiveAct, &QAction::toggled, this, &TextFindWidget::updateSearchOptions);
     connect(mWholeWordAct, &QAction::toggled, this, &TextFindWidget::updateSearchOptions);
+    connect(mRegExpAct, &QAction::toggled, this, &TextFindWidget::updateSearchOptions);
     connect(mSearch, &QLineEdit::textChanged, this, &TextFindWidget::slotAutoSearch);
 }
 
@@ -116,19 +120,6 @@ TextFindWidget::~TextFindWidget()
 {
 }
 
-QRegExp TextFindWidget::findRegExp() const
-{
-    QString str = QRegExp::escape(mSearch->text());
-    if (mWholeWordAct->isChecked()) {
-        str = QLatin1String("\\b") + str + QLatin1String("\\b");
-    }
-    if (mCaseSensitiveAct->isChecked()) {
-        return QRegExp(str, Qt::CaseSensitive);
-    } else {
-        return QRegExp(str, Qt::CaseInsensitive);
-    }
-}
-
 void TextFindWidget::setFoundMatch(bool match)
 {
 #ifndef QT_NO_STYLE_STYLESHEET
@@ -165,11 +156,37 @@ void TextFindWidget::slotAutoSearch(const QString &str)
     }
 }
 
-QLineEdit *TextFindWidget::search() const
+QLineEdit *TextFindWidget::searchLineEdit() const
 {
     return mSearch;
 }
 
+bool TextFindWidget::isRegularExpression() const
+{
+    return mRegExpAct->isChecked();
+}
+
+QString TextFindWidget::searchText() const
+{
+    return mSearch->text();
+}
+
+QRegExp TextFindWidget::searchRegExp() const
+{
+    QRegExp reg;
+    if (mCaseSensitiveAct->isChecked()) {
+        reg.setCaseSensitivity(Qt::CaseSensitive);
+    } else {
+        reg.setCaseSensitivity(Qt::CaseInsensitive);
+    }
+    QString searchTextString = mSearch->text();
+    if (mWholeWordAct->isChecked()) {
+        searchTextString = QStringLiteral("\\b") + searchTextString + QStringLiteral("\\b");
+    }
+    reg.setPattern(searchTextString);
+    return reg;
+}
+
 QTextDocument::FindFlags TextFindWidget::searchOptions() const
 {
     QTextDocument::FindFlags opt = nullptr;
