@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -36,10 +36,15 @@ public:
 
     QTextDocument::FindFlags searchOptions() const;
 
-    QLineEdit *search() const;
+    QLineEdit *searchLineEdit() const;
 
     void setFoundMatch(bool match);
-    QRegExp findRegExp() const;
+
+    bool isRegularExpression() const;
+
+    QRegExp searchRegExp() const;
+
+    QString searchText() const;
 
 private Q_SLOTS:
     void slotAutoSearch(const QString &str);
@@ -56,6 +61,7 @@ private:
     QLineEdit *mSearch = nullptr;
     QAction *mCaseSensitiveAct = nullptr;
     QAction *mWholeWordAct = nullptr;
+    QAction *mRegExpAct = nullptr;
 
     QPushButton *mFindPrevBtn = nullptr;
     QPushButton *mFindNextBtn = nullptr;
@@ -68,7 +74,7 @@ public:
     explicit TextReplaceWidget(QWidget *parent = nullptr);
     ~TextReplaceWidget();
 
-    QLineEdit *replace() const;
+    QLineEdit *replaceLineEdit() const;
 
 public Q_SLOTS:
     void slotSearchStringEmpty(bool);
